# opentracing-compose

An Opentracing tracer that composes multiple other tracers.
Used to trace to multiple Opentracing implementations at once.

## License

MIT.

---
Copyright (c) 2020 Brian Downing
